aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorGravatar A. Unique TensorFlower <gardener@tensorflow.org>2016-08-31 14:49:07 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2016-08-31 16:04:58 -0700
commit5aee7330167a11c0cf8c0c5bd1fb1162a8237e0a (patch)
tree1361308d403d95a45a9602d2ca43521c26bfc8b6
parent08beb079e778ef0f35ce0a41f6d602bd4218962f (diff)
I'm requesting a documentation revision for `range`.
The documentation for the `range` function was inconsistent in its documentation of optional parameters. Other documentation changes were reverted. Change: 131883258
-rw-r--r--tensorflow/python/ops/math_ops.py14
1 files changed, 8 insertions, 6 deletions
diff --git a/tensorflow/python/ops/math_ops.py b/tensorflow/python/ops/math_ops.py
index fa6af4740e..93c78b6254 100644
--- a/tensorflow/python/ops/math_ops.py
+++ b/tensorflow/python/ops/math_ops.py
@@ -974,13 +974,15 @@ def range(start, limit=None, delta=1, name="range"):
```
Args:
- start: A 0-D (scalar) of type `int32`. First entry in sequence.
- Defaults to 0.
+ start: A 0-D (scalar) of type `int32`. Acts as first entry in the range if
+ `limit` is not None; otherwise, acts as range limit and first entry
+ defaults to 0.
limit: A 0-D (scalar) of type `int32`. Upper limit of sequence,
- exclusive.
- delta: A 0-D `Tensor` (scalar) of type `int32`. Optional. Default is 1.
- Number that increments `start`.
- name: A name for the operation (optional).
+ exclusive. If None, defaults to the value of `start` while the first
+ entry of the range defaults to 0.
+ delta: A 0-D `Tensor` (scalar) of type `int32`. Number that increments
+ `start`. Defaults to 1.
+ name: A name for the operation. Defaults to "range".
Returns:
An 1-D `int32` `Tensor`.